load

Function load 

pub fn load<C>(path: impl AsRef<Path>) -> Result<C, Text>
where C: Decode<()> + Default + 'static,
Tries to load the cache stored by Duat for the given type

The cache must have been previously stored by cache::store. If it does not exist, or the buffer can’t be correctly interpreted, returns None